/**
 * Debug utility that wraps console methods and checks the global debug flag.
 */

/**
 * Checks if debug mode is enabled
 * @returns Whether debug mode is enabled
 */
function isDebugEnabled(): boolean {
  return typeof (globalThis as any).__SSE_DEBUG_ENABLED === 'boolean' 
    ? (globalThis as any).__SSE_DEBUG_ENABLED 
    : false;
}

/* eslint-disable no-console */
/**
 * Logs a debug message to the console if debug mode is enabled
 * @param args The arguments to log
 */
export const debugLog = (...args: any[]): void => {
  if (isDebugEnabled()) console.log('[SSE]', ...args);
};

/**
 * Logs an info message to the console if debug mode is enabled
 * @param args The arguments to log
 */
export const debugInfo = (...args: any[]): void => {
  if (isDebugEnabled()) console.info('[SSE]', ...args);
};

/**
 * Logs a warning message to the console if debug mode is enabled
 * @param args The arguments to log
 */
export const debugWarn = (...args: any[]): void => {
  if (isDebugEnabled()) console.warn('[SSE]', ...args);
};

/**
 * Logs an error message to the console if debug mode is enabled
 * @param args The arguments to log
 */
export const debugError = (...args: any[]): void => {
  if (isDebugEnabled()) console.error('[SSE]', ...args);
};
/* eslint-enable no-console */
